import { _TargetAddress } from "./_TargetAddress";
import { _Tag } from "./_Tag";
import { BrowserHttpOptions as __HttpOptions__ } from "@aws-sdk/types";
import * as __aws_sdk_types from "@aws-sdk/types";
/**
 * CreateResolverRuleInput shape
 */
export interface CreateResolverRuleInput {
    /**
     * <p>A unique string that identifies the request and that allows failed requests to be retried without the risk of executing the operation twice. <code>CreatorRequestId</code> can be any unique string, for example, a date/time stamp. </p>
     */
    CreatorRequestId: string;
    /**
     * <p>A friendly name that lets you easily find a rule in the Resolver dashboard in the Route 53 console.</p>
     */
    Name?: string;
    /**
     * <p>Specify <code>FORWARD</code>. Other resolver rule types aren't supported.</p>
     */
    RuleType: "FORWARD" | "SYSTEM" | "RECURSIVE" | string;
    /**
     * <p>DNS queries for this domain name are forwarded to the IP addresses that you specify in <code>TargetIps</code>. If a query matches multiple resolver rules (example.com and www.example.com), outbound DNS queries are routed using the resolver rule that contains the most specific domain name (www.example.com).</p>
     */
    DomainName: string;
    /**
     * <p>The IPs that you want Resolver to forward DNS queries to. You can specify only IPv4 addresses. Separate IP addresses with a comma.</p>
     */
    TargetIps?: Array<_TargetAddress> | Iterable<_TargetAddress>;
    /**
     * <p>The ID of the outbound resolver endpoint that you want to use to route DNS queries to the IP addresses that you specify in <code>TargetIps</code>.</p>
     */
    ResolverEndpointId?: string;
    /**
     * <p>A list of the tag keys and values that you want to associate with the endpoint.</p>
     */
    Tags?: Array<_Tag> | Iterable<_Tag>;
    /**
     * The maximum number of times this operation should be retried. If set, this value will override the `maxRetries` configuration set on the client for this command.
     */
    $maxRetries?: number;
    /**
     * An object that may be queried to determine if the underlying operation has been aborted.
     *
     * @see https://developer.mozilla.org/en-US/docs/Web/API/AbortSignal
     */
    $abortSignal?: __aws_sdk_types.AbortSignal;
    /**
     * Per-request HTTP configuration options. If set, any options specified will override the corresponding HTTP option set on the client for this command.
     */
    $httpOptions?: __HttpOptions__;
}
